package com.me.pacman.state;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.InputAdapter;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.me.pacman.FontRenderer;
import com.me.pacman.Score;
import com.me.pacman.PacDude;

public class HighScoreEntryState extends State {

    private Texture background;
    private Score score;

    private int currLetter;
    private char[] name;

    private boolean flash;
    private float elapsed;

    public HighScoreEntryState(PacDude game, Score score) {
        super(game);
        this.score = score;
        this.currLetter = 0;
        this.flash = false;
        this.elapsed = 0f;
        this.name = score.scorer.toCharArray();
    }

    @Override
    public void setup() {
        this.background = game.assets.getHighScoresBackground();
        Gdx.input.setInputProcessor(this.new Controller());
    }

    @Override
    public void render() {
        game.batch.draw(background, 0, 16);

        game.fontRenderer.setColor(Color.YELLOW);
        game.fontRenderer.draw(game.batch, "high scores", (8 * 8) + 4, 25 * 8);

        game.fontRenderer.setColor(Color.CHARTREUSE);
        game.fontRenderer.draw(game.batch, "score  name", (8 * 8) + 4, 22 * 8);

        game.fontRenderer.setColor(Color.BLUE);
        game.fontRenderer.draw(game.batch, "" + score.score, (8 * 8) + 4, 18 * 9);
        for (int i = 0; i < 3; i++) {
            game.fontRenderer.draw(game.batch, String.valueOf((i == currLetter && flash)? '_' : name[i]), (16 + i) * 8 + 4, 18 * 9);
        }

        game.fontRenderer.setColor(Color.WHITE);
        Score[] scores = game.highScores.getHighScores(9);
        for (int i = 0; i < scores.length; i++) {
            Score score = scores[i];
            game.fontRenderer.draw(game.batch, String.format("%-8d%s", score.score, score.scorer), (8 * 8) + 4, (17 - i) * 9);
        }
    }

    @Override
    public void update(float dt) {
        elapsed += dt;
        if (elapsed >= 1/3f) {
            elapsed = 0f;
            flash = !flash;
        }
    }

    @Override
    public void dispose() {
        Gdx.input.setInputProcessor(null);
    }

    private final class Controller extends InputAdapter {

        @Override
        public boolean keyDown(int keycode) {
            switch(keycode) {
                case Input.Keys.DOWN:
                    int nextIndex = FontRenderer.CHAR_TO_INDEX[name[currLetter]] - 1;
                    if (nextIndex < 0) {
                        nextIndex = 25;
                    }
                    flash = false;
                    name[currLetter] = FontRenderer.CHARS[nextIndex];
                    break;
                case Input.Keys.UP:
                    nextIndex = FontRenderer.CHAR_TO_INDEX[name[currLetter]] + 1;
                    if (nextIndex > 25) {
                        nextIndex = 0;
                    }
                    flash = false;
                    name[currLetter] = FontRenderer.CHARS[nextIndex];
                    break;
                case Input.Keys.RIGHT:
                    currLetter++;
                    if (currLetter > 2) {
                        currLetter = 0;
                    }
                    flash = true;
                    break;
                case Input.Keys.LEFT:
                    currLetter--;
                    if (currLetter < 0) {
                        currLetter = 2;
                    }
                    flash = true;
                    break;
                case Input.Keys.ENTER:
                    score.scorer = String.valueOf(name);
                    game.highScores.addScore(score);
                    game.setNextState(new HighScoresState(game));
                    break;
            }
            elapsed = 0f;
            return super.keyDown(keycode);
        }

    }

}
